import math
import matplotlib.pyplot as plt
import pyregion
import matplotlib.pyplot as plt
# from demo_helper import show_region

def demo_header():
    from astropy.io.fits import Header
    return Header.fromtextfile("sample_fits01.header")

region_list = [
    "test01_fk5_sexagecimal.reg",
    "test01_gal.reg",
    "test01_img.reg",
    "test01_ds9_physical.reg",
    "test01_fk5_degree.reg",
    "test01_mixed.reg",
    "test01_ciao.reg",
    "test01_ciao_physical.reg",
]

fig, ax = plt.subplots(1, num=1, clear=True)
h = demo_header()
reg_name = "test01_ciao.reg"
r = pyregion.open(reg_name).as_imagecoord(h)

patch_list, text_list = r.get_mpl_patches_texts()
for p in patch_list:
    ax.add_patch(p)
for t in text_list:
    ax.add_artist(t)
# patch_list[0].set_facecolor(None)

# ax_list = show_region(fig, region_list)
# for ax in ax_list:
ax.set_xlim(596, 1075)
ax.set_ylim(585, 1057)



import matplotlib.pyplot as plt
from demo_helper import show_region

region_list = [
    "test01_fk5_sexagecimal.reg",
    "test01_gal.reg",
    "test01_img.reg",
    "test01_ds9_physical.reg",
    "test01_fk5_degree.reg",
    "test01_mixed.reg",
    "test01_ciao.reg",
    "test01_ciao_physical.reg",
]

fig = plt.figure(1, figsize=(6, 5))
fig.clf()

ax_list = show_region(fig, region_list)
for ax in ax_list:
    ax.set_xlim(596, 1075)
    ax.set_ylim(585, 1057)

plt.draw()
plt.show()



# this contains imports plugins that configure py.test for astropy tests.
# by importing them here in conftest.py they are discoverable by py.test
# no matter how it is invoked within the source tree.

from astropy.version import version as astropy_version
if astropy_version < '3.0':
    # With older versions of Astropy, we actually need to import the pytest
    # plugins themselves in order to make them discoverable by pytest.
    from astropy.tests.pytest_plugins import *
else:
    # As of Astropy 3.0, the pytest plugins provided by Astropy are
    # automatically made available when Astropy is installed. This means it's
    # not necessary to import them here, but we still need to import global
    # variables that are used for configuration.
    from astropy.tests.plugins.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS

from astropy.tests.helper import enable_deprecations_as_exceptions

# Uncomment the following line to treat all DeprecationWarnings as exceptions
enable_deprecations_as_exceptions()

PYTEST_HEADER_MODULES.clear()
PYTEST_HEADER_MODULES.update([
    ('numpy', 'numpy'),
    ('cython', 'cython'),
    ('Astropy', 'astropy'),
    ('pyparsing', 'pyparsing'),
    ('matplotlib', 'matplotlib'),
])

# This is to figure out the affiliated package version, rather than
# using Astropy's
try:
    from .version import version
except ImportError:
    version = 'dev'

import os
packagename = os.path.basename(os.path.dirname(__file__))
TESTED_VERSIONS[packagename] = version



from astropy.io.fits import Header
import matplotlib.pyplot as plt
import pyregion


# read in the image
def demo_header():
    return Header.fromtextfile("sample_fits02.header")


header = demo_header()  # sample fits header
shape = (header["NAXIS1"], header["NAXIS2"])

reg_name = "test.reg"
r = pyregion.open(reg_name).as_imagecoord(header)
m = r.get_mask(shape=shape)

fig = plt.figure(1, figsize=(7, 5))
ax = plt.subplot(121)
plt.imshow(m, origin="lower")

patch_list, text_list = r.get_mpl_patches_texts()
for p in patch_list:
    ax.add_patch(p)
for t in text_list:
    ax.add_artist(t)

# another region

reg_name = "test02.reg"
r = pyregion.open(reg_name).as_imagecoord(header)
m = r.get_mask(shape=shape)

ax = plt.subplot(122)
plt.imshow(m, origin="lower")

patch_list, text_list = r.get_mpl_patches_texts()
for p in patch_list:
    ax.add_patch(p)
for t in text_list:
    ax.add_artist(t)

plt.show()



import math
import matplotlib.pyplot as plt
import pyregion


def demo_header():
    from astropy.io.fits import Header
    return Header.fromtextfile("sample_fits01.header")


def show_region(fig, region_list):
    h = demo_header()

    n = len(region_list)
    nx = int(math.ceil(n ** .5))
    ny = int(math.ceil(1. * n / nx))

    nrows_ncols = (ny, nx)

    grid = [plt.subplot(ny, nx, i + 1) for i in range(n)]

    for ax, reg_name in zip(grid, region_list):
        ax.set_aspect(1)

        r = pyregion.open(reg_name).as_imagecoord(h)

        patch_list, text_list = r.get_mpl_patches_texts()
        for p in patch_list:
            ax.add_patch(p)
        for t in text_list:
            ax.add_artist(t)

        if plt.rcParams["text.usetex"]:
            reg_name = reg_name.replace("_", r"\_")
        ax.set_title(reg_name, size=10)
        for t in ax.get_xticklabels() + ax.get_yticklabels():
            t.set_visible(False)

    return grid



#!/usr/bin/env python
# Licensed under a 3-clause BSD style license - see LICENSE.rst

import glob
import os
import sys

# ah_bootstrap fails with "python -m build". Disabling it for now.

import ah_bootstrap
from setuptools import setup

# A dirty hack to get around some early import/configurations ambiguities
if sys.version_info[0] >= 3:
    import builtins
else:
    import __builtin__ as builtins
builtins._ASTROPY_SETUP_ = True

from astropy_helpers.setup_helpers import (register_commands, get_debug_option,
                                           get_package_info)
from astropy_helpers.git_helpers import get_git_devstr
from astropy_helpers.version_helpers import generate_version_py

# Get some values from the setup.cfg
try:
    from ConfigParser import ConfigParser
except ImportError:
    from configparser import ConfigParser

conf = ConfigParser()
conf.read(['setup.cfg'])
metadata = dict(conf.items('metadata'))

PACKAGENAME = metadata.get('name', 'packagename')
DESCRIPTION = metadata.get('description', 'Astropy affiliated package')
AUTHOR = metadata.get('author', '')
AUTHOR_EMAIL = metadata.get('author_email', '')
LICENSE = metadata.get('license', 'unknown')
URL = metadata.get('url', 'http://astropy.org')

# It tries to import itself, which does not seem to work with 'python -m build'.
# Instead, put the description here. FIXME: This is a temporary workaround.

# Get the long description from the package's docstring
# __import__(PACKAGENAME)
# package = sys.modules[PACKAGENAME]
# LONG_DESCRIPTION = package.__doc__

LONG_DESCRIPTION = """
pyregion - a Python parser for ds9 region files

* Code : https://github.com/astropy/pyregion
* Docs : http://pyregion.readthedocs.io/

See also the in-development ``regions`` package
at https://github.com/astropy/regions
a new astronomy package for regions based on Astropy.
"""

# Store the package name in a built-in variable so it's easy
# to get from other parts of the setup infrastructure
builtins._ASTROPY_PACKAGE_NAME_ = PACKAGENAME

# VERSION should be PEP386 compatible (http://www.python.org/dev/peps/pep-0386)
# VERSION = '1.9.0'
VERSION = metadata.get("version")

# Indicates if this version is a release version
RELEASE = 'dev' not in VERSION

if not RELEASE:
    VERSION += get_git_devstr(False)

# Populate the dict of setup command overrides; this should be done before
# invoking any other functionality from distutils since it can potentially
# modify distutils' behavior.
cmdclassd = register_commands(PACKAGENAME, VERSION, RELEASE)

# Freeze build information in version.py
generate_version_py(PACKAGENAME, VERSION, RELEASE,
                    get_debug_option(PACKAGENAME))

# Treat everything in scripts except README.rst as a script to be installed
scripts = [fname for fname in glob.glob(os.path.join('scripts', '*'))
           if os.path.basename(fname) != 'README.rst']

# Get configuration information from all of the various subpackages.
# See the docstring for setup_helpers.update_package_files for more
# details.
package_info = get_package_info()

# Add the project-global data
package_info['package_data'].setdefault(PACKAGENAME, [])
package_info['package_data'][PACKAGENAME].append('data/*')

# Include all .c files, recursively, including those generated by
# Cython, since we can not do this in MANIFEST.in with a "dynamic"
# directory name.
c_files = []
for root, dirs, files in os.walk(PACKAGENAME):
    for filename in files:
        if filename.endswith('.c'):
            c_files.append(
                os.path.join(
                    os.path.relpath(root, PACKAGENAME), filename))
package_info['package_data'][PACKAGENAME].extend(c_files)

install_requires = [
    'pyparsing>=2.0',
    'numpy',
    'Cython',
    'astropy>=1.0',
]

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Science/Research',
    'License :: OSI Approved :: MIT License',
    'Operating System :: MacOS :: MacOS X',
    'Operating System :: POSIX :: Linux',
    'Programming Language :: Cython',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Topic :: Scientific/Engineering :: Astronomy',
]

setup(
    name=PACKAGENAME,
    version=VERSION,
    description=DESCRIPTION,
    scripts=scripts,
    install_requires=install_requires,
    provides=[PACKAGENAME],
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license=LICENSE,
    url=URL,
    long_description=LONG_DESCRIPTION,
    cmdclass=cmdclassd,
    zip_safe=False,
    use_2to3=False,
    classifiers=classifiers,
    **package_info
)



import matplotlib.pyplot as plt
import pyregion

reg_name = "test04_img.reg"

ax = plt.subplot(111)
ax.set_xlim(600, 1100)
ax.set_ylim(600, 1100)
ax.set_aspect(1)

r = pyregion.open(reg_name)

patch_list, text_list = r.get_mpl_patches_texts()
for p in patch_list:
    ax.add_patch(p)
for t in text_list:
    ax.add_artist(t)

plt.draw()
plt.show()
